import httpRequest from '@/utils/axios'
import type { ChannelRequestParams } from './types'

// https://gitlab.ezijing.com/root/api-documents/-/blob/master/%E6%96%B0%E7%9A%84zws%E7%B3%BB%E7%BB%9F/%E6%B8%A0%E9%81%93%E7%AE%A1%E7%90%86.md

// 获取渠道相关的公共map
export function getChannelMap() {
  return httpRequest.get('/api/zws/v1/backend/channel/conditions')
}

// 获取渠道角色
export function getRoles() {
  return httpRequest.get('/api/zws/v1/backend/common/channel-roles')
}

// 获取渠道列表
export function getChannelList(params?: {
  channel_id?: string
  title?: string
  company_short_name?: string
  tags?: string
  service_dialog_status?: string
  case_withdraw_status?: string
  distribution_status?: string
  channel_quality?: string
  'per-page'?: number
  page?: number
}) {
  return httpRequest.get('/api/zws/v1/backend/channel/list', { params })
}

// 获取渠道详情
export function getChannelDetail(params: { id: string }) {
  return httpRequest.get('/api/zws/v1/backend/channel/view', { params })
}

// 创建渠道
export function createChannel(data: ChannelRequestParams) {
  return httpRequest.post('/api/zws/v1/backend/channel/create', data, {
    headers: { 'Content-Type': 'multipart/form-data' }
  })
}

// 更新渠道
export function updateChannel(data: { id: string } & ChannelRequestParams) {
  return httpRequest.post('/api/zws/v1/backend/channel/update', data, {
    headers: { 'Content-Type': 'multipart/form-data' }
  })
}

// 删除渠道
export function deleteChannel(data: { id: string }) {
  return httpRequest.post('/api/zws/v1/backend/channel/delete', data)
}

// 获取成员列表
export function getMemberList(params: { id: string; 'per-page'?: number; page?: number }) {
  return httpRequest.get('/api/zws/v1/backend/channel/member', { params })
}

// 新增渠道成员
export function addMember(data: { user_id: string; channels_id: string; roles: string; type?: string }) {
  return httpRequest.post('/api/zws/v1/backend/channel/member-create', data)
}

// 删除成员
export function deleteMember(data: { user_id: string; channel_id: string; role_id: string }) {
  return httpRequest.post('/api/zws/v1/backend/channel/member-delete', data)
}

// 获取渠道项目列表
export function getProjectList(params: { id: string; 'per-page'?: number; page?: number }) {
  return httpRequest.get('/api/zws/v1/backend/channel/project', { params })
}

// 新增渠道项目
export function addProject(data: any) {
  return httpRequest.post('/api/zws/v1/backend/channel/project-create', data, {
    headers: { 'Content-Type': 'multipart/form-data' }
  })
}

// 更新渠道项目
export function updateProject(data: any) {
  return httpRequest.post('/api/zws/v1/backend/channel/project-update', data, {
    headers: { 'Content-Type': 'multipart/form-data' }
  })
}

// 删除渠道项目
export function deleteProject(data: { id: string; contract_id: string }) {
  return httpRequest.post('/api/zws/v1/backend/channel/project-delete', data)
}

// 批量设置标签
export function bindTag(data: { channels_id: string; tags: string }) {
  return httpRequest.post('/api/zws/v1/backend/channel/tag-create', data)
}

// 生成二维码
export function getQrcode(params: { id: string; project_id: string }) {
  return httpRequest.get('/api/zws/v1/backend/channel/qrcode', { params })
}
