export interface ChannelItem {
  id: string
  title: string
  channel_id: string
  channel_type: string
  tags: string[]
  service_phone: string
  service_dialog_status: string
  landing_page: string
  summary: string
  project_id: string
  channel_status: string
  comment: string
  status: string
  operator: string
  created_time: string
  updated_time: string
  channel_quality: string
  distribution_status: string
  case_withdraw_status: string
  call_status: string
  channel_owner_user_id: string
  channel_type_name: string
  channel_status_name: string
  channel_owner_user_id_name: string
}

export interface ChannelRequestParams {
  channel_type: string
  title: string
  service_phone: string
  channel_owner_user_id: string
  channel_status: string
  tags: string
  summary: string
  comment: string
  channel_quality: string
  distribution_status: string
  case_withdraw_status: string
  service_dialog_status: string
  partner: any
  leaders_id: string
  members?: string
  projects?: string
}

export type ChannelFormData = Omit<ChannelRequestParams, 'tags' | 'members' | 'projects'> & {
  tags: string[]
  channel_id: string
  channel_owner_user_id_name?: string
  members: ChannelMember[]
  projects: ChannelProject[]
  files: any
}

// 渠道成员
export interface ChannelMember {
  user_id: string
  role_id: string
  updated_time: string
  name: string
  mobile: string
  email: string
  role_name: string
}

// 渠道项目
export interface ChannelProject {
  id: string
  partner_profile_id: string
  project_id: string
  type: string
  conversion_type: string
  division_proportion: string
  location_limit: string
  unpaid_list_limit: string
  contract_document: string
  contract_signature_time: string
  follower_user_id: string
  expire_month: string
  comment: string
  status: string
  operator: string
  created_time: string
  updated_time: string
  expire_range_month_start: string
  expire_range_month_end: string
  division_rule: string
  secondary_channel_id: string
  secondary_division_type: string
  secondary_division_rule: string
  secondary_division_proportion: string
  secondary_contract_document: string
  project_id_name: string
  division_rule_name: string
  division_proportion_name: string
  expire_range: string
  follower_user_id_name: null
  conversion_type_name: string
  type_name: string
  secondary_channel_id_name: string
  secondary_division_type_name: string
  secondary_division_rule_name: string
  secondary_division_proportion_name: string
}

// 用户信息
export interface User {
  id: string
  realname: string
  nickname: string
  username: string
  mobile: string
  avatar: string
  email: string
}

// 角色信息
export interface Role {
  id: string
  name: string
  desc: string
  levels: RoleLevel[]
}

export interface RoleLevel {
  level_id: string
  level_name: string
  level_tag: string
  level_group_tag: string
}
